Method: GRPC::RpcServer#wait_till_running

Defined in:
src/ruby/lib/grpc/generic/rpc_server.rb

#wait_till_running(timeout = nil) ⇒ true, false

Is called from other threads to wait for #run to start up the server.

If run has not been called, this returns immediately.

Parameters:

  • timeout (Numeric) (defaults to: nil)

    number of seconds to wait

Returns:

  • (true, false)

    true if the server is running, false otherwise



294
295
296
297
298
299
# File 'src/ruby/lib/grpc/generic/rpc_server.rb', line 294

def wait_till_running(timeout = nil)
  @run_mutex.synchronize do
    @run_cond.wait(@run_mutex, timeout) if @running_state == :not_started
    return @running_state == :running
  end
end