Class: NamedTests

Inherits:
Object
  • Object
show all
Includes:
GRPC::Core::MetadataKeys, Grpc::Testing, Grpc::Testing::PayloadType
Defined in:
src/ruby/pb/test/client.rb

Overview

defines methods corresponding to each interop test case.

Constant Summary

Constants included from Grpc::Testing

Grpc::Testing::BoolValue, Grpc::Testing::ClientConfigureRequest, Grpc::Testing::ClientConfigureResponse, Grpc::Testing::EchoStatus, Grpc::Testing::Empty, Grpc::Testing::EmptyMessage, Grpc::Testing::GaugeRequest, Grpc::Testing::GaugeResponse, Grpc::Testing::GrpclbRouteType, Grpc::Testing::HookRequest, Grpc::Testing::HookResponse, Grpc::Testing::LoadBalancerAccumulatedStatsRequest, Grpc::Testing::LoadBalancerAccumulatedStatsResponse, Grpc::Testing::LoadBalancerStatsRequest, Grpc::Testing::LoadBalancerStatsResponse, Grpc::Testing::MemorySize, Grpc::Testing::Payload, Grpc::Testing::PayloadType, Grpc::Testing::ReconnectInfo, Grpc::Testing::ReconnectParams, Grpc::Testing::ResponseParameters, Grpc::Testing::SetReturnStatusRequest, Grpc::Testing::SimpleRequest, Grpc::Testing::SimpleResponse, Grpc::Testing::StreamingInputCallRequest, Grpc::Testing::StreamingInputCallResponse, Grpc::Testing::StreamingOutputCallRequest, Grpc::Testing::StreamingOutputCallResponse, Grpc::Testing::TestOrcaReport

Instance Method Summary collapse

Constructor Details

#initialize(stub, args) ⇒ NamedTests

Returns a new instance of NamedTests.



260
261
262
263
# File 'src/ruby/pb/test/client.rb', line 260

def initialize(stub, args)
  @stub = stub
  @args = args
end

Instance Method Details

#allObject



669
670
671
672
673
674
675
676
# File 'src/ruby/pb/test/client.rb', line 669

def all
  all_methods = NamedTests.instance_methods(false).map(&:to_s)
  all_methods.each do |m|
    next if m == 'all' || m.start_with?('assert')
    p "TESTCASE: #{m}"
    method(m).call
  end
end

#cancel_after_beginObject



480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'src/ruby/pb/test/client.rb', line 480

def cancel_after_begin
  msg_sizes = [27_182, 8, 1828, 45_904]
  reqs = msg_sizes.map do |x|
    req = Payload.new(body: nulls(x))
    StreamingInputCallRequest.new(payload: req)
  end
  op = @stub.streaming_input_call(reqs, return_op: true)
  op.cancel
  op.execute
  fail 'Should have raised GRPC:Cancelled'
rescue GRPC::Cancelled
  assert("#{__callee__}: call operation should be CANCELLED") { op.cancelled? }
end

#cancel_after_first_responseObject



494
495
496
497
498
499
500
501
502
503
504
# File 'src/ruby/pb/test/client.rb', line 494

def cancel_after_first_response
  msg_sizes = [[27_182, 31_415], [8, 9], [1828, 2653], [45_904, 58_979]]
  ppp = PingPongPlayer.new(msg_sizes)
  op = @stub.full_duplex_call(ppp.each_item, return_op: true)
  ppp.canceller_op = op  # causes ppp to cancel after the 1st message
  op.execute.each { |r| ppp.queue.push(r) }
  fail 'Should have raised GRPC:Cancelled'
rescue GRPC::Cancelled
  assert("#{__callee__}: call operation should be CANCELLED") { op.cancelled? }
  op.wait
end

#client_compressed_streamingObject



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'src/ruby/pb/test/client.rb', line 390

def client_compressed_streaming
  # first request used also by the probe
  first_request = StreamingInputCallRequest.new(
    payload: Payload.new(type: :COMPRESSABLE, body: nulls(27_182)),
    expect_compressed: BoolValue.new(value: true)
  )

  # send a probe to see if CompressedResponse is supported on the server
  send_probe_for_compressed_request_support do
    request_uncompressed_args = {
      COMPRESSION_REQUEST_ALGORITHM => 'identity'
    }
    @stub.streaming_input_call([first_request],
                               metadata: request_uncompressed_args)
  end

  second_request = StreamingInputCallRequest.new(
    payload: Payload.new(type: :COMPRESSABLE, body: nulls(45_904)),
    expect_compressed: BoolValue.new(value: false)
  )

  # Create the requests messages and the corresponding write flags
  # for each message
  requests = WriteFlagSettingStreamingInputEnumerable.new([
    { request: first_request,
      write_flag: 0 },
    { request: second_request,
      write_flag: GRPC::Core::WriteFlags::NO_COMPRESS }
  ])

  # Create the call_op, pass it to the requests enumerable, and
  # run the call
  call_op = @stub.streaming_input_call(requests,
                                       return_op: true)
  requests.call_op = call_op
  resp = call_op.execute

  wanted_aggregate_size = 73_086

  assert("#{__callee__}: aggregate payload size is incorrect") do
    wanted_aggregate_size == resp.aggregated_payload_size
  end
end

#client_compressed_unaryObject



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'src/ruby/pb/test/client.rb', line 274

def client_compressed_unary
  # first request used also for the probe
  req_size, wanted_response_size = 271_828, 314_159
  expect_compressed = BoolValue.new(value: true)
  payload = Payload.new(type: :COMPRESSABLE, body: nulls(req_size))
  req = SimpleRequest.new(response_type: :COMPRESSABLE,
                          response_size: wanted_response_size,
                          payload: payload,
                          expect_compressed: expect_compressed)

  # send a probe to see if CompressedResponse is supported on the server
  send_probe_for_compressed_request_support do
    request_uncompressed_args = {
      COMPRESSION_REQUEST_ALGORITHM => 'identity'
    }
    @stub.unary_call(req, metadata: request_uncompressed_args)
  end

  # make a call with a compressed message
  resp = @stub.unary_call(req)
  assert('Expected second unary call with compression to work') do
    resp.payload.body.length == wanted_response_size
  end

  # make a call with an uncompressed message
  stub_options = {
    COMPRESSION_REQUEST_ALGORITHM => 'identity'
  }

  req = SimpleRequest.new(
    response_type: :COMPRESSABLE,
    response_size: wanted_response_size,
    payload: payload,
    expect_compressed: BoolValue.new(value: false)
  )

  resp = @stub.unary_call(req, metadata: stub_options)
  assert('Expected second unary call with compression to work') do
    resp.payload.body.length == wanted_response_size
  end
end

#client_streamingObject



377
378
379
380
381
382
383
384
385
386
387
388
# File 'src/ruby/pb/test/client.rb', line 377

def client_streaming
  msg_sizes = [27_182, 8, 1828, 45_904]
  wanted_aggregate_size = 74_922
  reqs = msg_sizes.map do |x|
    req = Payload.new(body: nulls(x))
    StreamingInputCallRequest.new(payload: req)
  end
  resp = @stub.streaming_input_call(reqs)
  assert("#{__callee__}: aggregate payload size is incorrect") do
    wanted_aggregate_size == resp.aggregated_payload_size
  end
end

#compute_engine_credsObject



339
340
341
342
343
344
345
# File 'src/ruby/pb/test/client.rb', line 339

def compute_engine_creds
  resp = perform_large_unary(fill_username: true,
                             fill_oauth_scope: true)
  assert("#{__callee__}: bad username") do
    @args. == resp.username
  end
end

#custom_metadataObject



585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
# File 'src/ruby/pb/test/client.rb', line 585

def 

  # Function wide constants
  req_size, wanted_response_size = 271_828, 314_159
   = "x-grpc-test-echo-initial"
   = "test_initial_metadata_value"
   = "x-grpc-test-echo-trailing-bin"
   = "\x0a\x0b\x0a\x0b\x0a\x0b"

   = {
     => ,
     => 
  }

  # Testing with UnaryCall
  payload = Payload.new(type: :COMPRESSABLE, body: nulls(req_size))
  req = SimpleRequest.new(response_type: :COMPRESSABLE,
      response_size: wanted_response_size,
      payload: payload)

  op = @stub.unary_call(req, metadata: , return_op: true)
  op.execute
  if not op..has_key?()
    fail AssertionError, "Expected initial metadata. None received"
  elsif op.[] != []
    fail AssertionError,
           "Expected initial metadata: #{metadata[initial_metadata_key]}. "\
           "Received: #{op.metadata[initial_metadata_key]}"
  end
  if not op..has_key?()
    fail AssertionError, "Expected trailing metadata. None received"
  elsif op.[] !=
        []
    fail AssertionError,
          "Expected trailing metadata: #{metadata[trailing_metadata_key]}. "\
          "Received: #{op.trailing_metadata[trailing_metadata_key]}"
  end

  # Testing with FullDuplex
  req_cls, p_cls = StreamingOutputCallRequest, ResponseParameters
  duplex_req = req_cls.new(payload: Payload.new(body: nulls(req_size)),
                response_type: :COMPRESSABLE,
                response_parameters: [p_cls.new(size: wanted_response_size)])

  duplex_op = @stub.full_duplex_call([duplex_req], metadata: ,
                                      return_op: true)
  resp = duplex_op.execute
  resp.each { |r| } # ensures that the server sends trailing data
  duplex_op.wait
  if not duplex_op..has_key?()
    fail AssertionError, "Expected initial metadata. None received"
  elsif duplex_op.[] !=
        []
    fail AssertionError,
           "Expected initial metadata: #{metadata[initial_metadata_key]}. "\
           "Received: #{duplex_op.metadata[initial_metadata_key]}"
  end
  if not duplex_op.[]
    fail AssertionError, "Expected trailing metadata. None received"
  elsif duplex_op.[] !=
        []
    fail AssertionError,
        "Expected trailing metadata: #{metadata[trailing_metadata_key]}. "\
        "Received: #{duplex_op.trailing_metadata[trailing_metadata_key]}"
  end

end

#empty_streamObject



467
468
469
470
471
472
473
474
475
476
477
478
# File 'src/ruby/pb/test/client.rb', line 467

def empty_stream
  ppp = PingPongPlayer.new([])
  resps = @stub.full_duplex_call(ppp.each_item)
  count = 0
  resps.each do |r|
    ppp.queue.push(r)
    count += 1
  end
  assert("#{__callee__}: too many responses expected 0") do
    count == 0
  end
end

#empty_unaryObject



265
266
267
268
# File 'src/ruby/pb/test/client.rb', line 265

def empty_unary
  resp = @stub.empty_call(Empty.new)
  assert('empty_unary: invalid response') { resp.is_a?(Empty) }
end

#jwt_token_credsObject



332
333
334
335
336
337
# File 'src/ruby/pb/test/client.rb', line 332

def jwt_token_creds
  json_key = File.read(ENV[AUTH_ENV])
  wanted_email = JSON.parse(json_key)['client_email']
  resp = perform_large_unary(fill_username: true)
  assert("#{__callee__}: bad username") { wanted_email == resp.username }
end

#large_unaryObject



270
271
272
# File 'src/ruby/pb/test/client.rb', line 270

def large_unary
  perform_large_unary
end

#oauth2_auth_tokenObject



347
348
349
350
351
352
353
354
355
356
# File 'src/ruby/pb/test/client.rb', line 347

def oauth2_auth_token
  resp = perform_large_unary(fill_username: true,
                             fill_oauth_scope: true)
  json_key = File.read(ENV[AUTH_ENV])
  wanted_email = JSON.parse(json_key)['client_email']
  assert("#{__callee__}: bad username") { wanted_email == resp.username }
  assert("#{__callee__}: bad oauth scope") do
    @args.oauth_scope.include?(resp.oauth_scope)
  end
end

#per_rpc_credsObject



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'src/ruby/pb/test/client.rb', line 358

def per_rpc_creds
  auth_creds = Google::Auth.get_application_default(@args.oauth_scope)
   = proc do |md|
    kw = auth_creds.updater_proc.call({})
  end

  call_creds = GRPC::Core::CallCredentials.new()

  resp = perform_large_unary(fill_username: true,
                             fill_oauth_scope: true,
                             credentials: call_creds)
  json_key = File.read(ENV[AUTH_ENV])
  wanted_email = JSON.parse(json_key)['client_email']
  assert("#{__callee__}: bad username") { wanted_email == resp.username }
  assert("#{__callee__}: bad oauth scope") do
    @args.oauth_scope.include?(resp.oauth_scope)
  end
end

#ping_pongObject



451
452
453
454
455
456
# File 'src/ruby/pb/test/client.rb', line 451

def ping_pong
  msg_sizes = [[27_182, 31_415], [8, 9], [1828, 2653], [45_904, 58_979]]
  ppp = PingPongPlayer.new(msg_sizes)
  resps = @stub.full_duplex_call(ppp.each_item)
  resps.each { |r| ppp.queue.push(r) }
end

#server_streamingObject



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'src/ruby/pb/test/client.rb', line 434

def server_streaming
  msg_sizes = [31_415, 9, 2653, 58_979]
  response_spec = msg_sizes.map { |s| ResponseParameters.new(size: s) }
  req = StreamingOutputCallRequest.new(response_type: :COMPRESSABLE,
                                       response_parameters: response_spec)
  resps = @stub.streaming_output_call(req)
  resps.each_with_index do |r, i|
    assert("#{__callee__}: too many responses") { i < msg_sizes.length }
    assert("#{__callee__}: payload body #{i} has the wrong length") do
      msg_sizes[i] == r.payload.body.length
    end
    assert("#{__callee__}: payload type is wrong") do
      :COMPRESSABLE == r.payload.type
    end
  end
end

#service_account_credsObject



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'src/ruby/pb/test/client.rb', line 316

def 
  # ignore this test if the oauth options are not set
  if @args.oauth_scope.nil?
    p 'NOT RUN: service_account_creds; no service_account settings'
    return
  end
  json_key = File.read(ENV[AUTH_ENV])
  wanted_email = JSON.parse(json_key)['client_email']
  resp = perform_large_unary(fill_username: true,
                             fill_oauth_scope: true)
  assert("#{__callee__}: bad username") { wanted_email == resp.username }
  assert("#{__callee__}: bad oauth scope") do
    @args.oauth_scope.include?(resp.oauth_scope)
  end
end

#special_status_messageObject



653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
# File 'src/ruby/pb/test/client.rb', line 653

def special_status_message
  code = GRPC::Core::StatusCodes::UNKNOWN
  message = "\t\ntest with whitespace\r\nand Unicode BMP ☺ and non-BMP 😈\t\n"
  req = SimpleRequest.new(
    response_status: EchoStatus.new(code: code, message: message))
  begin
    resp = @stub.unary_call(req)
    fail AssertionError, "GRPC::Unknown should have been raised."
  rescue GRPC::Unknown => e
    if e.details.force_encoding("UTF-8") != message
      fail AssertionError,
        "Expected message #{message}. Received: #{e.details}"
    end
  end
end

#status_code_and_messageObject



528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
# File 'src/ruby/pb/test/client.rb', line 528

def status_code_and_message

  # Function wide constants.
  message = "test status method"
  code = GRPC::Core::StatusCodes::UNKNOWN

  # Testing with UnaryCall.
  payload = Payload.new(type: :COMPRESSABLE, body: nulls(1))
  echo_status = EchoStatus.new(code: code, message: message)
  req = SimpleRequest.new(response_type: :COMPRESSABLE,
      response_size: 1,
      payload: payload,
      response_status: echo_status)
  seen_correct_exception = false
  begin
    resp = @stub.unary_call(req)
  rescue GRPC::Unknown => e
    if e.details != message
     fail AssertionError,
       "Expected message #{message}. Received: #{e.details}"
    end
    seen_correct_exception = true
  rescue Exception => e
    fail AssertionError, "Expected BadStatus. Received: #{e.inspect}"
  end

  if not seen_correct_exception
    fail AssertionError, "Did not see expected status from UnaryCall"
  end

  # testing with FullDuplex
  req_cls, p_cls = StreamingOutputCallRequest, ResponseParameters
  duplex_req = req_cls.new(payload: Payload.new(body: nulls(1)),
                response_type: :COMPRESSABLE,
                response_parameters: [p_cls.new(size: 1)],
                response_status: echo_status)
  seen_correct_exception = false
  begin
    resp = @stub.full_duplex_call([duplex_req])
    resp.each { |r| }
  rescue GRPC::Unknown => e
    if e.details != message
      fail AssertionError,
        "Expected message #{message}. Received: #{e.details}"
    end
    seen_correct_exception = true
  rescue Exception => e
    fail AssertionError, "Expected BadStatus. Received: #{e.inspect}"
  end

  if not seen_correct_exception
    fail AssertionError, "Did not see expected status from FullDuplexCall"
  end

end

#timeout_on_sleeping_serverObject



458
459
460
461
462
463
464
465
# File 'src/ruby/pb/test/client.rb', line 458

def timeout_on_sleeping_server
  enum = BlockingEnumerator.new(27_182, 2)
  deadline = GRPC::Core::TimeConsts::from_relative_time(1)
  resps = @stub.full_duplex_call(enum.each_item, deadline: deadline)
  resps.each { } # wait to receive each request (or timeout)
  fail 'Should have raised GRPC::DeadlineExceeded'
rescue GRPC::DeadlineExceeded
end

#unimplemented_methodObject



506
507
508
509
510
511
512
513
514
515
# File 'src/ruby/pb/test/client.rb', line 506

def unimplemented_method
  begin
    resp = @stub.unimplemented_call(Empty.new)
  rescue GRPC::Unimplemented => e
    return
  rescue Exception => e
    fail AssertionError, "Expected BadStatus. Received: #{e.inspect}"
  end
  fail AssertionError, "GRPC::Unimplemented should have been raised. Was not."
end

#unimplemented_serviceObject



517
518
519
520
521
522
523
524
525
526
# File 'src/ruby/pb/test/client.rb', line 517

def unimplemented_service
  begin
    resp = @stub.unimplemented_call(Empty.new)
  rescue GRPC::Unimplemented => e
    return
  rescue Exception => e
    fail AssertionError, "Expected BadStatus. Received: #{e.inspect}"
  end
  fail AssertionError, "GRPC::Unimplemented should have been raised. Was not."
end