Method: SynchronizedCancellationService#initialize

Defined in:
src/ruby/spec/generic/rpc_server_spec.rb

#initialize(notify_request_received, wait_until_rpc_cancelled) ⇒ SynchronizedCancellationService

notify_request_received and wait_until_rpc_cancelled are callbacks to synchronously allow the client to proceed with cancellation (after the unary request has been received), and to synchronously wait until the client has cancelled the current RPC.



100
101
102
103
# File 'src/ruby/spec/generic/rpc_server_spec.rb', line 100

def initialize(notify_request_received, wait_until_rpc_cancelled)
  @notify_request_received = notify_request_received
  @wait_until_rpc_cancelled = wait_until_rpc_cancelled
end